==> openshift-model-operator-5.8.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/OpenShiftSDNConfigBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OpenShiftSDNConfigBuilder extends io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfigFluentImpl<io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfig,io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfigBuilder>{
  public OpenShiftSDNConfigBuilder() {
    this(false);
  }
  public OpenShiftSDNConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new OpenShiftSDNConfig(), validationEnabled);
  }
  public OpenShiftSDNConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public OpenShiftSDNConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OpenShiftSDNConfig(), validationEnabled);
  }
  public OpenShiftSDNConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfigFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfig instance) {
    this(fluent, instance, false);
  }
  public OpenShiftSDNConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfigFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withEnableUnidling(instance.getEnableUnidling()); 
    fluent.withMode(instance.getMode()); 
    fluent.withMtu(instance.getMtu()); 
    fluent.withUseExternalOpenvswitch(instance.getUseExternalOpenvswitch()); 
    fluent.withVxlanPort(instance.getVxlanPort()); 
    this.validationEnabled = validationEnabled; 
  }
  public OpenShiftSDNConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfig instance) {
    this(instance,false);
  }
  public OpenShiftSDNConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withEnableUnidling(instance.getEnableUnidling()); 
    this.withMode(instance.getMode()); 
    this.withMtu(instance.getMtu()); 
    this.withUseExternalOpenvswitch(instance.getUseExternalOpenvswitch()); 
    this.withVxlanPort(instance.getVxlanPort()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfig build() {
    OpenShiftSDNConfig buildable = new OpenShiftSDNConfig(fluent.getEnableUnidling(),fluent.getMode(),fluent.getMtu(),fluent.getUseExternalOpenvswitch(),fluent.getVxlanPort());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OpenShiftSDNConfigBuilder that = (OpenShiftSDNConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.4-sources.jar: io/fabric8/openshift/api/model/operator/v1/OpenShiftSDNConfigBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OpenShiftSDNConfigBuilder extends io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfigFluentImpl<io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfig,io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfigBuilder>{
  public OpenShiftSDNConfigBuilder() {
    this(false);
  }
  public OpenShiftSDNConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new OpenShiftSDNConfig(), validationEnabled);
  }
  public OpenShiftSDNConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public OpenShiftSDNConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OpenShiftSDNConfig(), validationEnabled);
  }
  public OpenShiftSDNConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfigFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfig instance) {
    this(fluent, instance, false);
  }
  public OpenShiftSDNConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfigFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withEnableUnidling(instance.getEnableUnidling()); 
    fluent.withMode(instance.getMode()); 
    fluent.withMtu(instance.getMtu()); 
    fluent.withUseExternalOpenvswitch(instance.getUseExternalOpenvswitch()); 
    fluent.withVxlanPort(instance.getVxlanPort()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OpenShiftSDNConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfig instance) {
    this(instance,false);
  }
  public OpenShiftSDNConfigBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withEnableUnidling(instance.getEnableUnidling()); 
    this.withMode(instance.getMode()); 
    this.withMtu(instance.getMtu()); 
    this.withUseExternalOpenvswitch(instance.getUseExternalOpenvswitch()); 
    this.withVxlanPort(instance.getVxlanPort()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.OpenShiftSDNConfig build() {
    OpenShiftSDNConfig buildable = new OpenShiftSDNConfig(fluent.getEnableUnidling(),fluent.getMode(),fluent.getMtu(),fluent.getUseExternalOpenvswitch(),fluent.getVxlanPort());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OpenShiftSDNConfigBuilder that = (OpenShiftSDNConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
